/*
 * FISG - Output Modules Header
 * Programmed and designed by Matti 'ccr' Hamalainen
 * (C) Copyright 2003 Tecnic Software productions (TNSP)
 *
 * Please read file 'COPYING' for information on license and distribution.
 */
#ifndef _OUT_FORMATS_H
#define _OUT_FORMATS_H

#include <stdio.h>
#include "fisg.h"
#include "th_config.h"

/*
 * Typedefs
 */
typedef struct {
	char	*ofName,
		*ofDescription;
	
	int (*ofFunction)(FILE *, t_stats *, t_config *);
} t_outformat;


extern const t_outformat	outputFormats[];
extern const int		nOutputFormats;

#endif /* _OUT_FORMATS_H */
